@@ -21,7 +21,7 @@ if name="$( source gtop 2>&1 )"; then
     fi
   cd - > /dev/null || exit 1
 else
-  error.sh gall "${name}"; exit 1
+  error.sh pull "${name}"; exit 1
 fi
 
 unset starting name path error error1
