@@ -2,7 +2,7 @@
 ## source
 # shellcheck disable=SC2034
 export starting="${BASH_SOURCE[0]}"; debug.sh starting
-set -x
+
 test -n "${BASHRC_FILE}" || { error.bash BASHRC_FILE 'not defined'; return 1; }
 
 function home_bashrc() {
@@ -84,13 +84,16 @@ function home_secrets() {
     cd "${GITHUB_SECRETS_PATH}"  || { error.sh "${GITHUB_SECRETS_PATH}" "invalid"; return 1; }
     if ! git log > /dev/null 2>&1; then
       if git clone "${GITHUB_SECRETS_URL}" /tmp/"$( basename "${GITHUB_SECRETS_PATH}" )" --quiet; then
-        if rsync -aq /tmp/"$( basename "${GITHUB_SECRETS_PATH}" )" "${GITHUB_SECRETS_PATH}"; then
-          gpull.sh
-#          sudo rm -rf /tmp/"$( basename "${GITHUB_SECRETS_PATH}" )"/
-          info.sh clone "${GITHUB_SECRETS_URL}" "not empty dir"
+        if rsync -aq /tmp/"$( basename "${GITHUB_SECRETS_PATH}" )" "$( dirname "${GITHUB_SECRETS_PATH}" )"; then
+          if gpull.sh; then
+          sudo rm -rf /tmp/"$( basename "${GITHUB_SECRETS_PATH}" )"/
+            info.sh clone "${GITHUB_SECRETS_URL}" "not empty dir"
+          else
+            error.sh clone "not valid git after rsync"; return 1
+          fi
         else
-#          sudo rm -rf /tmp/"$( basename "${GITHUB_SECRETS_PATH}" )"/
-          error.sh clone "cp clone to tmp"; return 1
+          sudo rm -rf /tmp/"$( basename "${GITHUB_SECRETS_PATH}" )"/
+          error.sh clone "rsync clone to tmp"; return 1
         fi
       else
         error.sh clone "${GITHUB_SECRETS_URL}" /tmp/"$( basename "${GITHUB_SECRETS_PATH}" )"; return 1
@@ -146,5 +149,5 @@ if test "${USER}" = "${USERNAME}" && isuser.sh; then
   home_file || exit 1
   home_links || exit 1
 fi
-set +x
+
 unset starting bashrc_path
